"""update image caching templates

Revision ID: 8605707dacc8
Revises: 1aacf11f8ba4
Create Date: 2022-10-14 12:17:25.328147

"""
from alembic import op


# revision identifiers, used by Alembic.
revision = "8605707dacc8"
down_revision = "1aacf11f8ba4"
branch_labels = None
depends_on = None

new_condor = """executable = vlass_image_caching.sh
arguments = {{calibration_name}} {{phase_center}} {{vlass_relative_path}} {{qa_status}}

output = image_caching.out
error = image_caching.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
PIMS_PATH = /lustre/aoc/cluster/pipeline/vlass_{{vlass_env}}/workspaces/bin
VLASS_DIR = {{data_location}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(PIMS_PATH)/pimscache, nraorsync://$(PIMS_PATH)/cacheImagingProducts.sh
when_to_transfer_output = ON_EXIT
transfer_output_files = .job.ad
output_destination = nraorsync://$(VLASS_DIR)
+WantIOProxy = True

getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = (VLASS == True) && (HasLustre == True)
+partition = "VLASS"

queue

"""
old_condor = """executable = vlass_image_caching.sh
arguments = {{calibration_name}} {{phase_center}} {{vlass_relative_path}} {{qa_status}}

output = image_caching.out
error = image_caching.err
log = condor.log

PIMS_PATH = /lustre/aoc/cluster/pipeline/vlass_{{vlass_env}}/workspaces/bin
VLASS_DIR = {{data_location}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(PIMS_PATH)/pimscache, nraorsync://$(PIMS_PATH)/cacheImagingProducts.sh
when_to_transfer_output = ON_EXIT
transfer_output_files = .job.ad
output_destination = nraorsync://$(VLASS_DIR)
+WantIOProxy = True

getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = (VLASS == True) && (HasLustre == True)
+partition = "VLASS"

queue
"""

new_script = """#!/bin/sh
export CAPO_PROFILE=vlass.{{vlass_env}}

./pimscache -rm -c $1 -p $2

./cacheImagingProducts.sh -p $3 -s $4
"""
old_script = """#!/bin/sh

./pimscache -rm -c $1 -p $2

./cacheImagingProducts.sh -p $3 -s $4
"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{new_condor}' WHERE filename='vlass_image_caching.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{new_script}' WHERE filename='vlass_image_caching.sh'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_condor}' WHERE filename='vlass_image_caching.condor'
        """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{old_script}' WHERE filename='vlass_image_caching.sh'
            """
    )
